@@ -78,7 +78,7 @@ BcdClockWidget::~BcdClockWidget(){
 }
 
 QSize BcdClockWidget::sizeHint(){
-    return QSize((((showSeconds) ? 6 : 4) * hoursOneWidget->getElementSize()) + (2 * layout->margin()) + 35,
+    return QSize((((showSeconds) ? 6 : 4) * hoursOneWidget->getElementSize()) + (((showSeconds) ? 5 : 3) * layout->margin()),
                  (4 * hoursOneWidget->getElementSize()) + (2 * layout->margin())
 #ifdef Q_WS_MAEMO_5
                  + 6
