@@ -33,13 +33,9 @@ public:
     explicit BinaryClockWidget(QWidget *parent = 0);
     ~BinaryClockWidget();
 
-    void setLedSize(int size);
-    void setLedBorder(int border);
-    void setLedColor(const QColor &color);
-
     QSize sizeHint();
 
-private slots:
+protected slots:
     void updateTime();
 
 private:
