@@ -47,6 +47,16 @@ BinaryDisplayWidget::BinaryDisplayWidget(int bits, int value, int widgetSize, QW
     ledPen.setWidth(DEFAULT_LED_PEN_WIDTH);
 }
 
+void BinaryDisplayWidget::applySettings(){
+    QSettings settings;
+    setLedBorder(settings.value(SettingsDialog::LED_BORDER,
+                                SettingsDialog::LED_BORDER_DEFAULT).toInt());
+    setLedColor(settings.value(SettingsDialog::CLOCK_LED_COLOR,
+                                SettingsDialog::CLOCK_LED_COLOR_DEFAULT).value<QColor>());
+    setLedSize(settings.value(SettingsDialog::LED_SIZE,
+                                SettingsDialog::LED_SIZE_DEFAULT).toInt());
+}
+
 void BinaryDisplayWidget::drawLed(int x, int y, bool on, QPainter *painter){
     int elementSize = getElementSize();
 
@@ -103,13 +113,6 @@ void BinaryDisplayWidget::updateValue(int value){
     }
 }
 
-void BinaryDisplayWidget::setLedSize(int size){
-    if(ledSize != size){
-        ledSize = size;
-        emit update();
-    }
-}
-
 void BinaryDisplayWidget::setLedBorder(int border){
     if(this->ledBorder != border){
         this->ledBorder = border;
@@ -126,3 +129,10 @@ void BinaryDisplayWidget::setLedPen(const QPen &pen){
     ledPen = pen;
     emit update();
 }
+
+void BinaryDisplayWidget::setLedSize(int size){
+    if(ledSize != size){
+        ledSize = size;
+        emit update();
+    }
+}
