@@ -17,11 +17,17 @@
  *  along with Binary Clock.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <QSettings>
+
 #include "clockwidget.h"
+#include "settingsdialog.h"
 
 ClockWidget::ClockWidget(QWidget *parent) :
     QWidget(parent)
 {
+    QSettings settings;
+    showSeconds = settings.value(SettingsDialog::SHOW_SECONDS, SettingsDialog::SHOW_SECONDS_DEFAULT).toBool();
+
     timer = new QTimer();
     connect(timer, SIGNAL(timeout()), this, SLOT(updateTime()));
     timer->start(1000);
@@ -33,6 +39,10 @@ ClockWidget::~ClockWidget(){
     delete timer;
 }
 
+void ClockWidget::applySettings(){
+    emit settingsChanged();
+}
+
 void ClockWidget::resumeClock(bool resume){
     if(resume){
         updateTime();
