@@ -35,15 +35,18 @@ public:
     explicit ClockWidget(QWidget *parent = 0);
     ~ClockWidget();
 
-    virtual void setLedSize(int size) = 0;
-    virtual void setLedBorder(int border) = 0;
-    virtual void setLedColor(const QColor &color) = 0;
-
     virtual QSize sizeHint() = 0;
 
 public slots:
+    virtual void applySettings();
     void resumeClock(bool pause);
 
+signals:
+    void settingsChanged();
+
+protected:
+    bool showSeconds;
+
 protected slots:
     virtual void updateTime() = 0;
 
