@@ -21,6 +21,11 @@
 #include <QIcon>
 #include <QSettings>
 
+#include "bcdclockwidget.h"
+#include "binaryclockwidget.h"
+#include "unixtimewidget.h"
+#include "unixtimebchwidget.h"
+
 #include "mainwidget.h"
 #include "settingsdialog.h"
 
@@ -216,6 +221,12 @@ void MainWidget::setClock(int clockStyle){
     case 1:
         clockWidget = new BcdClockWidget();
         break;
+    case 2:
+        clockWidget = new UnixTimeWidget();
+        break;
+    case 3:
+        clockWidget = new UnixTimeBchWidget();
+        break;
     default:
         clockWidget = new BinaryClockWidget();
         break;
